%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% calculateB
% Carlos J. Cela, Jan 2012
%
% Calculates B field on a given point from current flowing on an
% arbitrary path given by points in p
%
% Usage:
%         [B] = calculateB(p, x, y, z)
%
%         where
%               p = array of point of conductor in the order of
%                   current flow.
%               x = x coordinate of point where to calculate B
%               y = y coordinate of point where to calculate B
%               z = z coordinate of point where to calculate B
%               B = total B field at point
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [B] = calculateB(p, x, y, z)
  % Initialize B field at point to zero
  B = [0 0 0]; 

  % Calculate dl  
  s=size(p);
  numberOfPoints = s(1)-1;
  dl = p(2:numberOfPoints+1,:)-p(1:numberOfPoints,:);

  % Add dB contribution from each segment
  % of the coil, stored in dl array
  mu0 = 4*pi*1e-7;
  for index = 1:s-1
    r = [x y z] - p(index,:);
    rmag = sqrt(r(1)^2+r(2)^2+r(3)^2);
    runit = r./rmag;
    c = mu0*1/(4*pi*rmag^2);
    B = B + c*cross(dl(index,:),runit);
  end
end


function [c] = cross(a, b)
  c(1) = a(2)*b(3)-a(3)*b(2);
  c(2) = a(3)*b(1)-a(1)*b(3);
  c(3) = a(1)*b(2)-a(2)*b(1);
end


