%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% calculateCoilPoints
% Carlos J. Cela, Jan 2012
%
% Calculates array of coordinates of the points that make the coils. These
% correspond to the tip and tail of the dl vector in the in the 
% order that gives the direction of circulation of the current. The first
% point is repeated at the end of the array to help 'wrapping' the vectors.
%
% Usage:
%         [Bx, By, Bz] = calculateB( x, y, z)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [p] = calculateCoilPoints()

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Coil parameters
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  position = [ 1 0 1]; % Position of center of coil
  radius = 0.25;       % Radius of coil
  steps = 100;         % Number of segments considered for coil

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Calculate endpoints for each coil segment
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  % p(a,b) holds all point position. 'a' is
  % the point number, 'b' is 1,2,3 for x,y,z
  % coordinates respectively
  
  % Sweep angle in direction of current .Repeat 1st point 
  % at end of array to ease vector calculations later
  % i.e. 0 and 2*pi are the same point 
  n = 0;
  for angle = 0:2*pi/steps:2*pi;
    n = n+1;
    zpos = position(3)+radius * sin(angle);
    xpos = position(1)+radius * cos(angle);

    % Store points in array
    p(n,1) = xpos; % X coordinate of point n
    p(n,2) = 0;    % Y coordinate of point n
    p(n,3) = zpos; % Z coordinate of point n
  end
end


