%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotCoil
% Carlos J. Cela, Jan 2012
%
% Plots coil and current direction for visual verification
%
% Usage:
%         plotCoil(p)
%
%     where p is the array of points.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plotCoil(p)

  % Plot coil geometry
  figure(1);
  scatter3(p(:,1),p(:,2),p(:,3));
  xlabel('X-axis');  
  ylabel('Y-axis');  
  zlabel('Z-axis');
  title('Coil points');
  
  % Plot current direcion
  figure(2);
  s = size(p);
  len = s(1);

  x = p(1:len-1,1); % Position X
  y = p(1:len-1,2); % Position Y
  z = p(1:len-1,3); % Position Z
  u = p(2:len,1)-p(1:len-1,1);  % X component of dl
  v = p(2:len,2)-p(1:len-1,2);  % Y component of dl
  w = p(2:len,3)-p(1:len-1,3);  % Z component of dl

  quiver3(x, y, z, u, v, w);
  xlabel('X-axis');  
  ylabel('Y-axis');  
  zlabel('Z-axis');
  title('dl direction along coil');
end


